Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterCuebePluginServiceServer(s grpc.ServiceRegistrar, srv CuebePluginServiceServer)
- type ConfigurePluginRequest
- type ConfigurePluginRequest_builder
- type ConfigurePluginResponse
- func (x *ConfigurePluginResponse) GetBackends() map[string]*ConfigurePluginResponse_BackendDescription
- func (*ConfigurePluginResponse) ProtoMessage()
- func (x *ConfigurePluginResponse) ProtoReflect() protoreflect.Message
- func (x *ConfigurePluginResponse) Reset()
- func (x *ConfigurePluginResponse) SetBackends(v map[string]*ConfigurePluginResponse_BackendDescription)
- func (x *ConfigurePluginResponse) String() string
- type ConfigurePluginResponse_BackendDescription
- func (x *ConfigurePluginResponse_BackendDescription) GetOutputs() []string
- func (*ConfigurePluginResponse_BackendDescription) ProtoMessage()
- func (x *ConfigurePluginResponse_BackendDescription) ProtoReflect() protoreflect.Message
- func (x *ConfigurePluginResponse_BackendDescription) Reset()
- func (x *ConfigurePluginResponse_BackendDescription) SetOutputs(v []string)
- func (x *ConfigurePluginResponse_BackendDescription) String() string
- type ConfigurePluginResponse_BackendDescription_builder
- type ConfigurePluginResponse_builder
- type CuebePluginServiceClient
- type CuebePluginServiceServer
- type PerformTaskRequest
- func (x *PerformTaskRequest) ClearBackend()
- func (x *PerformTaskRequest) ClearOutDirectory()
- func (x *PerformTaskRequest) ClearParameters()
- func (x *PerformTaskRequest) GetBackend() string
- func (x *PerformTaskRequest) GetInputs() []string
- func (x *PerformTaskRequest) GetOutDirectory() string
- func (x *PerformTaskRequest) GetParameters() *structpb.Value
- func (x *PerformTaskRequest) HasBackend() bool
- func (x *PerformTaskRequest) HasOutDirectory() bool
- func (x *PerformTaskRequest) HasParameters() bool
- func (*PerformTaskRequest) ProtoMessage()
- func (x *PerformTaskRequest) ProtoReflect() protoreflect.Message
- func (x *PerformTaskRequest) Reset()
- func (x *PerformTaskRequest) SetBackend(v string)
- func (x *PerformTaskRequest) SetInputs(v []string)
- func (x *PerformTaskRequest) SetOutDirectory(v string)
- func (x *PerformTaskRequest) SetParameters(v *structpb.Value)
- func (x *PerformTaskRequest) String() string
- type PerformTaskRequest_builder
- type PerformTaskResponse
- type PerformTaskResponse_builder
- type UnimplementedCuebePluginServiceServer
- type UnsafeCuebePluginServiceServer
Constants ¶
const ( CuebePluginService_ConfigurePlugin_FullMethodName = "/backend.plugin.proto.CuebePluginService/ConfigurePlugin" CuebePluginService_PerformTask_FullMethodName = "/backend.plugin.proto.CuebePluginService/PerformTask" )
Variables ¶
var CuebePluginService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "backend.plugin.proto.CuebePluginService", HandlerType: (*CuebePluginServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "ConfigurePlugin", Handler: _CuebePluginService_ConfigurePlugin_Handler, }, { MethodName: "PerformTask", Handler: _CuebePluginService_PerformTask_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "backend/plugin/proto/plugin.proto", }
CuebePluginService_ServiceDesc is the grpc.ServiceDesc for CuebePluginService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_backend_plugin_proto_plugin_proto protoreflect.FileDescriptor
Functions ¶
func RegisterCuebePluginServiceServer ¶
func RegisterCuebePluginServiceServer(s grpc.ServiceRegistrar, srv CuebePluginServiceServer)
Types ¶
type ConfigurePluginRequest ¶
type ConfigurePluginRequest struct {
// contains filtered or unexported fields
}
func (*ConfigurePluginRequest) ProtoMessage ¶
func (*ConfigurePluginRequest) ProtoMessage()
func (*ConfigurePluginRequest) ProtoReflect ¶
func (x *ConfigurePluginRequest) ProtoReflect() protoreflect.Message
func (*ConfigurePluginRequest) Reset ¶
func (x *ConfigurePluginRequest) Reset()
func (*ConfigurePluginRequest) String ¶
func (x *ConfigurePluginRequest) String() string
type ConfigurePluginRequest_builder ¶
type ConfigurePluginRequest_builder struct {
// contains filtered or unexported fields
}
func (ConfigurePluginRequest_builder) Build ¶
func (b0 ConfigurePluginRequest_builder) Build() *ConfigurePluginRequest
type ConfigurePluginResponse ¶
type ConfigurePluginResponse struct {
// contains filtered or unexported fields
}
func (*ConfigurePluginResponse) GetBackends ¶
func (x *ConfigurePluginResponse) GetBackends() map[string]*ConfigurePluginResponse_BackendDescription
func (*ConfigurePluginResponse) ProtoMessage ¶
func (*ConfigurePluginResponse) ProtoMessage()
func (*ConfigurePluginResponse) ProtoReflect ¶
func (x *ConfigurePluginResponse) ProtoReflect() protoreflect.Message
func (*ConfigurePluginResponse) Reset ¶
func (x *ConfigurePluginResponse) Reset()
func (*ConfigurePluginResponse) SetBackends ¶
func (x *ConfigurePluginResponse) SetBackends(v map[string]*ConfigurePluginResponse_BackendDescription)
func (*ConfigurePluginResponse) String ¶
func (x *ConfigurePluginResponse) String() string
type ConfigurePluginResponse_BackendDescription ¶
type ConfigurePluginResponse_BackendDescription struct {
// contains filtered or unexported fields
}
func (*ConfigurePluginResponse_BackendDescription) GetOutputs ¶
func (x *ConfigurePluginResponse_BackendDescription) GetOutputs() []string
func (*ConfigurePluginResponse_BackendDescription) ProtoMessage ¶
func (*ConfigurePluginResponse_BackendDescription) ProtoMessage()
func (*ConfigurePluginResponse_BackendDescription) ProtoReflect ¶
func (x *ConfigurePluginResponse_BackendDescription) ProtoReflect() protoreflect.Message
func (*ConfigurePluginResponse_BackendDescription) Reset ¶
func (x *ConfigurePluginResponse_BackendDescription) Reset()
func (*ConfigurePluginResponse_BackendDescription) SetOutputs ¶
func (x *ConfigurePluginResponse_BackendDescription) SetOutputs(v []string)
func (*ConfigurePluginResponse_BackendDescription) String ¶
func (x *ConfigurePluginResponse_BackendDescription) String() string
type ConfigurePluginResponse_BackendDescription_builder ¶
type ConfigurePluginResponse_BackendDescription_builder struct {
Outputs []string
// contains filtered or unexported fields
}
type ConfigurePluginResponse_builder ¶
type ConfigurePluginResponse_builder struct {
Backends map[string]*ConfigurePluginResponse_BackendDescription
// contains filtered or unexported fields
}
func (ConfigurePluginResponse_builder) Build ¶
func (b0 ConfigurePluginResponse_builder) Build() *ConfigurePluginResponse
type CuebePluginServiceClient ¶
type CuebePluginServiceClient interface {
ConfigurePlugin(ctx context.Context, in *ConfigurePluginRequest, opts ...grpc.CallOption) (*ConfigurePluginResponse, error)
PerformTask(ctx context.Context, in *PerformTaskRequest, opts ...grpc.CallOption) (*PerformTaskResponse, error)
}
CuebePluginServiceClient is the client API for CuebePluginService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewCuebePluginServiceClient ¶
func NewCuebePluginServiceClient(cc grpc.ClientConnInterface) CuebePluginServiceClient
type CuebePluginServiceServer ¶
type CuebePluginServiceServer interface {
ConfigurePlugin(context.Context, *ConfigurePluginRequest) (*ConfigurePluginResponse, error)
PerformTask(context.Context, *PerformTaskRequest) (*PerformTaskResponse, error)
// contains filtered or unexported methods
}
CuebePluginServiceServer is the server API for CuebePluginService service. All implementations must embed UnimplementedCuebePluginServiceServer for forward compatibility.
type PerformTaskRequest ¶
type PerformTaskRequest struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
func (*PerformTaskRequest) ClearBackend ¶
func (x *PerformTaskRequest) ClearBackend()
func (*PerformTaskRequest) ClearOutDirectory ¶
func (x *PerformTaskRequest) ClearOutDirectory()
func (*PerformTaskRequest) ClearParameters ¶
func (x *PerformTaskRequest) ClearParameters()
func (*PerformTaskRequest) GetBackend ¶
func (x *PerformTaskRequest) GetBackend() string
func (*PerformTaskRequest) GetInputs ¶
func (x *PerformTaskRequest) GetInputs() []string
func (*PerformTaskRequest) GetOutDirectory ¶
func (x *PerformTaskRequest) GetOutDirectory() string
func (*PerformTaskRequest) GetParameters ¶
func (x *PerformTaskRequest) GetParameters() *structpb.Value
func (*PerformTaskRequest) HasBackend ¶
func (x *PerformTaskRequest) HasBackend() bool
func (*PerformTaskRequest) HasOutDirectory ¶
func (x *PerformTaskRequest) HasOutDirectory() bool
func (*PerformTaskRequest) HasParameters ¶
func (x *PerformTaskRequest) HasParameters() bool
func (*PerformTaskRequest) ProtoMessage ¶
func (*PerformTaskRequest) ProtoMessage()
func (*PerformTaskRequest) ProtoReflect ¶
func (x *PerformTaskRequest) ProtoReflect() protoreflect.Message
func (*PerformTaskRequest) Reset ¶
func (x *PerformTaskRequest) Reset()
func (*PerformTaskRequest) SetBackend ¶
func (x *PerformTaskRequest) SetBackend(v string)
func (*PerformTaskRequest) SetInputs ¶
func (x *PerformTaskRequest) SetInputs(v []string)
func (*PerformTaskRequest) SetOutDirectory ¶
func (x *PerformTaskRequest) SetOutDirectory(v string)
func (*PerformTaskRequest) SetParameters ¶
func (x *PerformTaskRequest) SetParameters(v *structpb.Value)
func (*PerformTaskRequest) String ¶
func (x *PerformTaskRequest) String() string
type PerformTaskRequest_builder ¶
type PerformTaskRequest_builder struct {
Backend *string
Inputs []string
Parameters *structpb.Value
OutDirectory *string
// contains filtered or unexported fields
}
func (PerformTaskRequest_builder) Build ¶
func (b0 PerformTaskRequest_builder) Build() *PerformTaskRequest
type PerformTaskResponse ¶
type PerformTaskResponse struct {
// contains filtered or unexported fields
}
func (*PerformTaskResponse) ProtoMessage ¶
func (*PerformTaskResponse) ProtoMessage()
func (*PerformTaskResponse) ProtoReflect ¶
func (x *PerformTaskResponse) ProtoReflect() protoreflect.Message
func (*PerformTaskResponse) Reset ¶
func (x *PerformTaskResponse) Reset()
func (*PerformTaskResponse) String ¶
func (x *PerformTaskResponse) String() string
type PerformTaskResponse_builder ¶
type PerformTaskResponse_builder struct {
// contains filtered or unexported fields
}
func (PerformTaskResponse_builder) Build ¶
func (b0 PerformTaskResponse_builder) Build() *PerformTaskResponse
type UnimplementedCuebePluginServiceServer ¶
type UnimplementedCuebePluginServiceServer struct{}
UnimplementedCuebePluginServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedCuebePluginServiceServer) ConfigurePlugin ¶
func (UnimplementedCuebePluginServiceServer) ConfigurePlugin(context.Context, *ConfigurePluginRequest) (*ConfigurePluginResponse, error)
func (UnimplementedCuebePluginServiceServer) PerformTask ¶
func (UnimplementedCuebePluginServiceServer) PerformTask(context.Context, *PerformTaskRequest) (*PerformTaskResponse, error)
type UnsafeCuebePluginServiceServer ¶
type UnsafeCuebePluginServiceServer interface {
// contains filtered or unexported methods
}
UnsafeCuebePluginServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to CuebePluginServiceServer will result in compilation errors.